@@ -6,9 +6,6 @@ use autodie;
 
 use Socket;
 
-# bug in this module: it breaks when loaded dynamically
-use Socket::MsgHdr;
-
 use Data::Dumper;
 
 use FindBin;
@@ -18,9 +15,9 @@ use Protocol::DBus::Client;
 
 my $dbus = Protocol::DBus::Client::system();
 
-use Carp::Always;
+$dbus->preserve_variant_signatures(1);
 
-$dbus->do_authn();
+$dbus->initialize();
 
 my $got_response;
 
