@@ -6,7 +6,7 @@ use autodie;
 
 use Socket;
 
-# bug in this module: it breaks when loaded dynamically
+# Required for unix FD support
 use Socket::MsgHdr;
 
 use Data::Dumper;
@@ -18,7 +18,11 @@ use Protocol::DBus::Client;
 
 my $dbus = Protocol::DBus::Client::system();
 
-$dbus->do_authn();
+# $dbus->big_endian(1);
+
+$dbus->initialize();
+
+my $signal_name = 'ProtocolDBusFDPass';
 
 $dbus->send_call(
     member => 'AddMatch',
@@ -27,7 +31,7 @@ $dbus->send_call(
     interface => 'org.freedesktop.DBus',
     path => '/org/freedesktop/DBus',
     body => [
-       "type='signal'",
+       "type=signal,member=$signal_name",
     ]
 );
 
@@ -38,12 +42,12 @@ my $recv_name = $dbus->get_connection_name();
 my $pid = fork or do {
     my $dbus = Protocol::DBus::Client::system();
 
-    $dbus->do_authn();
+    $dbus->initialize();
 
-    pipe my $r, my $w;
+    pipe( my $r, my $w );
 
     $dbus->send_signal(
-        member => 'AddMatch',  # hey, it works
+        member => $signal_name,
         signature => 'h',
         destination => $recv_name,
         interface => 'org.freedesktop.DBus',
